"""
WSGI config for d08 project.

It exposes the WSGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/howto/deployment/wsgi/
"""

import os
from whitenoise import WhiteNoise
from django.core.wsgi import get_wsgi_application

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "d08.settings")
application = get_wsgi_application()
application = WhiteNoise(application, root="")
application.add_files("/static/", prefix="")
application.add_files("/media/", prefix="")
